@@ -13,14 +13,14 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
-
-#include <gconf/gconf-backend.h>
-#include <gconf/gconf-internals.h>
-#include <gconf/gconf.h>
+#include <config.h>
+#include "gconf/gconf-backend.h"
+#include "gconf/gconf-internals.h"
+#include "gconf/gconf.h"
 
 #include <stdio.h>
 #include <time.h>
@@ -429,15 +429,15 @@ tree_lookup_entry (MarkupTree *tree,
   else
     dir = markup_tree_lookup_dir (tree, parent, &error);
 
+  g_free (parent);
+  parent = NULL;
+  
   if (error != NULL)
     {
       g_propagate_error (err, error);
       return NULL;
     }
   
-  g_free (parent);
-  parent = NULL;
-  
   if (dir != NULL)
     {
       const char *relative_key;
